package main

import (
	"encoding/base64"
	"fmt"
	"net/http"
	"os"
	"path/filepath"
	"strings"
	"text/template"

	"code.ivysaur.me/webdir/thumbnail"
)

func (this *WebdirApp) RenderPath(w http.ResponseWriter, path string) {
	absPath, err := this.GetAbsPathFromRel(path)
	if err != nil {
		this.RenderError(w, 400, err)
		return
	}

	// Assert directory exists
	dirStat, err := os.Stat(absPath)
	if err != nil {
		this.RenderError(w, 404, err)
		return
	}

	if !dirStat.IsDir() {
		this.RenderError(w, 400, fmt.Errorf("Not a directory for '%s'\n", absPath))
		return
	}

	// Find items in abspath

	w.Header().Set("Content-Type", "text/html")
	w.WriteHeader(200)

	w.Write([]byte(`<!DOCTYPE html>
<html>
	<head>
		<title>` + template.HTMLEscapeString(path) + `</title>
		<meta charset="UTF-8">
		<link rel="stylesheet" type="text/css" href="/static/app.css">
	</head>
	<body>
		<div class="item-list">
	`))

	// Up-a-level?
	if len(absPath) > len(this.Basedir) {
		parent, _ := filepath.Split(path)
		if parent == path {
			parent = ""
		}
		b64Parent := base64.StdEncoding.EncodeToString([]byte(parent))
		w.Write([]byte(`<a class="item" href="/path/` + b64Parent + `"><div class="thumb folder"></div><span class="caption">[UP]</span></a>`))
	}

	// Files in directory
	filepath.Walk(absPath, func(name string, stat os.FileInfo, err error) error {

		if err != nil {
			return nil // skip??
		}

		b64Name := base64.StdEncoding.EncodeToString([]byte(filepath.Join(path, stat.Name())))
		hescName := template.HTMLEscapeString(stat.Name())
		compareName := strings.ToLower(stat.Name())

		class := "thumb"
		if len(compareName) > 0 && compareName[0] == '.' {
			class += " hidden"
		}

		if _, shouldExclude := this.ExcludeComponents[compareName]; shouldExclude {
			// skip

		} else if name == absPath {
			// skip

		} else if stat.IsDir() {
			w.Write([]byte(`<a class="item" href="/path/` + b64Name + `" title="` + hescName + `"><div class="` + class + ` folder"></div><span class="caption">` + hescName + `</span></a>`))
			return filepath.SkipDir

		} else if thumbnail.FiletypeSupported(filepath.Ext(compareName)) {
			w.Write([]byte(`<a class="item" href="/get/` + b64Name + `" title="` + hescName + `"><div class="` + class + `" style="background:url('/thumb/` + b64Name + `');"></div><span class="caption">` + hescName + `</span></a>`))

		} else {
			w.Write([]byte(`<a class="item" href="/get/` + b64Name + `" title="` + hescName + `"><div class="` + class + ` file"></div><span class="caption">` + hescName + `</span></a>`))

		}

		return nil
	})

	w.Write([]byte(`
		</div>
	</body>
</html>
	`))
}
